class DirectoryInfo(FileSystemInfo,ISerializable):
 """
 Exposes instance methods for creating,moving,and enumerating through directories and subdirectories. This class cannot be inherited.

 

 DirectoryInfo(path: str)
 """
 def Create(self,directorySecurity=None):
  """
  Create(self: DirectoryInfo,directorySecurity: DirectorySecurity)

   Creates a directory using a System.Security.AccessControl.DirectorySecurity object.

  

   directorySecurity: The access control to apply to the directory.

  Create(self: DirectoryInfo)

   Creates a directory.
  """
  pass
 def CreateSubdirectory(self,path,directorySecurity=None):
  """
  CreateSubdirectory(self: DirectoryInfo,path: str,directorySecurity: DirectorySecurity) -> DirectoryInfo

  

   Creates a subdirectory or subdirectories on the specified path with the specified security. The 

    specified path can be relative to this instance of the System.IO.DirectoryInfo class.

  

  

   path: The specified path. This cannot be a different disk volume or Universal Naming Convention (UNC) 

    name.

  

   directorySecurity: The security to apply.

   Returns: The last directory specified in path.

  CreateSubdirectory(self: DirectoryInfo,path: str) -> DirectoryInfo

  

   Creates a subdirectory or subdirectories on the specified path. The specified path can be 

    relative to this instance of the System.IO.DirectoryInfo class.

  

  

   path: The specified path. This cannot be a different disk volume or Universal Naming Convention (UNC) 

    name.

  

   Returns: The last directory specified in path.
  """
  pass
 def Delete(self,recursive=None):
  """
  Delete(self: DirectoryInfo,recursive: bool)

   Deletes this instance of a System.IO.DirectoryInfo,specifying whether to delete subdirectories 

    and files.

  

  

   recursive: true to delete this directory,its subdirectories,and all files; otherwise,false.

  Delete(self: DirectoryInfo)

   Deletes this System.IO.DirectoryInfo if it is empty.
  """
  pass
 def EnumerateDirectories(self,searchPattern=None,searchOption=None):
  """
  EnumerateDirectories(self: DirectoryInfo,searchPattern: str,searchOption: SearchOption) -> IEnumerable[DirectoryInfo]

  

   Returns an enumerable collection of directory information that matches a specified search 

    pattern and search subdirectory option.

  

  

   searchPattern: The search string. The default pattern is "*",which returns all directories.

   searchOption: One of the enumeration values that specifies whether the search operation should include only 

    the current directory or all subdirectories. The default value is 

    System.IO.SearchOption.TopDirectoryOnly.

  

   Returns: An enumerable collection of directories that matches searchPattern and searchOption.

  EnumerateDirectories(self: DirectoryInfo,searchPattern: str) -> IEnumerable[DirectoryInfo]

  

   Returns an enumerable collection of directory information that matches a specified search 

    pattern.

  

  

   searchPattern: The search string. The default pattern is "*",which returns all directories.

   Returns: An enumerable collection of directories that matches searchPattern.

  EnumerateDirectories(self: DirectoryInfo) -> IEnumerable[DirectoryInfo]

  

   Returns an enumerable collection of directory information in the current directory.

   Returns: An enumerable collection of directories in the current directory.
  """
  pass
 def EnumerateFiles(self,searchPattern=None,searchOption=None):
  """
  EnumerateFiles(self: DirectoryInfo,searchPattern: str,searchOption: SearchOption) -> IEnumerable[FileInfo]

  

   Returns an enumerable collection of file information that matches a specified search pattern and 

    search subdirectory option.

  

  

   searchPattern: The search string. The default pattern is "*",which returns all files.

   searchOption: One of the enumeration values that specifies whether the search operation should include only 

    the current directory or all subdirectories. The default value is 

    System.IO.SearchOption.TopDirectoryOnly.

  

   Returns: An enumerable collection of files that matches searchPattern and searchOption.

  EnumerateFiles(self: DirectoryInfo,searchPattern: str) -> IEnumerable[FileInfo]

  

   Returns an enumerable collection of file information that matches a search pattern.

  

   searchPattern: The search string. The default pattern is "*",which returns all files.

   Returns: An enumerable collection of files that matches searchPattern.

  EnumerateFiles(self: DirectoryInfo) -> IEnumerable[FileInfo]

  

   Returns an enumerable collection of file information in the current directory.

   Returns: An enumerable collection of the files in the current directory.
  """
  pass
 def EnumerateFileSystemInfos(self,searchPattern=None,searchOption=None):
  """
  EnumerateFileSystemInfos(self: DirectoryInfo,searchPattern: str,searchOption: SearchOption) -> IEnumerable[FileSystemInfo]

  

   Returns an enumerable collection of file system information that matches a specified search 

    pattern and search subdirectory option.

  

  

   searchPattern: The search string. The default pattern is "*",which returns all files or directories.

   searchOption: One of the enumeration values that specifies whether the search operation should include only 

    the current directory or all subdirectories. The default value is 

    System.IO.SearchOption.TopDirectoryOnly.

  

   Returns: An enumerable collection of file system information objects that matches searchPattern and 

    searchOption.

  

  EnumerateFileSystemInfos(self: DirectoryInfo,searchPattern: str) -> IEnumerable[FileSystemInfo]

  

   Returns an enumerable collection of file system information that matches a specified search 

    pattern.

  

  

   searchPattern: The search string. The default pattern is "*",which returns all files and directories.

   Returns: An enumerable collection of file system information objects that matches searchPattern.

  EnumerateFileSystemInfos(self: DirectoryInfo) -> IEnumerable[FileSystemInfo]

  

   Returns an enumerable collection of file system information in the current directory.

   Returns: An enumerable collection of file system information in the current directory.
  """
  pass
 def GetAccessControl(self,includeSections=None):
  """
  GetAccessControl(self: DirectoryInfo,includeSections: AccessControlSections) -> DirectorySecurity

  

   Gets a System.Security.AccessControl.DirectorySecurity object that encapsulates the specified 

    type of access control list (ACL) entries for the directory described by the current 

    System.IO.DirectoryInfo object.

  

  

   includeSections: One of the System.Security.AccessControl.AccessControlSections values that specifies the type of 

    access control list (ACL) information to receive.

  

   Returns: A System.Security.AccessControl.DirectorySecurity object that encapsulates the access control 

    rules for the file described by the path parameter.ExceptionsException 

    typeConditionSystem.SystemExceptionThe directory could not be found or 

    modified.System.UnauthorizedAccessExceptionThe current process does not have access to open the 

    directory.System.IO.IOExceptionAn I/O error occurred while opening the 

    directory.System.PlatformNotSupportedExceptionThe current operating system is not Microsoft 

    Windows 2000 or later.System.UnauthorizedAccessExceptionThe directory is read-only.-or- This 

    operation is not supported on the current platform.-or- The caller does not have the required 

    permission.

  

  GetAccessControl(self: DirectoryInfo) -> DirectorySecurity

  

   Gets a System.Security.AccessControl.DirectorySecurity object that encapsulates the access 

    control list (ACL) entries for the directory described by the current System.IO.DirectoryInfo 

    object.

  

   Returns: A System.Security.AccessControl.DirectorySecurity object that encapsulates the access control 

    rules for the directory.
  """
  pass
 def GetDirectories(self,searchPattern=None,searchOption=None):
  """
  GetDirectories(self: DirectoryInfo,searchPattern: str,searchOption: SearchOption) -> Array[DirectoryInfo]

  

   Returns an array of directories in the current System.IO.DirectoryInfo matching the given search 

    criteria and using a value to determine whether to search subdirectories.

  

  

   searchPattern: The search string. For example,"System*" can be used to search for all directories that begin 

    with the word "System".

  

   searchOption: One of the enumeration values that specifies whether the search operation should include only 

    the current directory or all subdirectories.

  

   Returns: An array of type DirectoryInfo matching searchPattern.

  GetDirectories(self: DirectoryInfo,searchPattern: str) -> Array[DirectoryInfo]

  

   Returns an array of directories in the current System.IO.DirectoryInfo matching the given search 

    criteria.

  

  

   searchPattern: The search string. For example,"System*" can be used to search for all directories that begin 

    with the word "System".

  

   Returns: An array of type DirectoryInfo matching searchPattern.

  GetDirectories(self: DirectoryInfo) -> Array[DirectoryInfo]

  

   Returns the subdirectories of the current directory.

   Returns: An array of System.IO.DirectoryInfo objects.
  """
  pass
 def GetFiles(self,searchPattern=None,searchOption=None):
  """
  GetFiles(self: DirectoryInfo) -> Array[FileInfo]

  

   Returns a file list from the current directory.

   Returns: An array of type System.IO.FileInfo.

  GetFiles(self: DirectoryInfo,searchPattern: str,searchOption: SearchOption) -> Array[FileInfo]

  

   Returns a file list from the current directory matching the given search pattern and using a 

    value to determine whether to search subdirectories.

  

  

   searchPattern: The search string. For example,"System*" can be used to search for all directories that begin 

    with the word "System".

  

   searchOption: One of the enumeration values that specifies whether the search operation should include only 

    the current directory or all subdirectories.

  

   Returns: An array of type System.IO.FileInfo.

  GetFiles(self: DirectoryInfo,searchPattern: str) -> Array[FileInfo]

  

   Returns a file list from the current directory matching the given search pattern.

  

   searchPattern: The search string,such as "*.txt".

   Returns: An array of type System.IO.FileInfo.
  """
  pass
 def GetFileSystemInfos(self,searchPattern=None,searchOption=None):
  """
  GetFileSystemInfos(self: DirectoryInfo) -> Array[FileSystemInfo]

  

   Returns an array of strongly typed System.IO.FileSystemInfo entries representing all the files 

    and subdirectories in a directory.

  

   Returns: An array of strongly typed System.IO.FileSystemInfo entries.

  GetFileSystemInfos(self: DirectoryInfo,searchPattern: str,searchOption: SearchOption) -> Array[FileSystemInfo]

  

   Retrieves an array of System.IO.FileSystemInfo objects that represent the files and 

    subdirectories matching the specified search criteria.

  

  

   searchPattern: The search string. The default pattern is "*",which returns all files and directories.

   searchOption: One of the enumeration values that specifies whether the search operation should include only 

    the current directory or all subdirectories. The default value is 

    System.IO.SearchOption.TopDirectoryOnly.

  

   Returns: An array of file system entries that match the search criteria.

  GetFileSystemInfos(self: DirectoryInfo,searchPattern: str) -> Array[FileSystemInfo]

  

   Retrieves an array of strongly typed System.IO.FileSystemInfo objects representing the files and 

    subdirectories that match the specified search criteria.

  

  

   searchPattern: The search string. For example,"System*" can be used to search for all directories that begin 

    with the word "System".

  

   Returns: An array of strongly typed FileSystemInfo objects matching the search criteria.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def MoveTo(self,destDirName):
  """
  MoveTo(self: DirectoryInfo,destDirName: str)

   Moves a System.IO.DirectoryInfo instance and its contents to a new path.

  

   destDirName: The name and path to which to move this directory. The destination cannot be another disk volume 

    or a directory with the identical name. It can be an existing directory to which you want to add 

    this directory as a subdirectory.
  """
  pass
 def SetAccessControl(self,directorySecurity):
  """
  SetAccessControl(self: DirectoryInfo,directorySecurity: DirectorySecurity)

   Applies access control list (ACL) entries described by a 

    System.Security.AccessControl.DirectorySecurity object to the directory described by the current 

    System.IO.DirectoryInfo object.

  

  

   directorySecurity: An object that describes an ACL entry to apply to the directory described by the path parameter.
  """
  pass
 def ToString(self):
  """
  ToString(self: DirectoryInfo) -> str

  

   Returns the original path that was passed by the user.

   Returns: Returns the original path that was passed by the user.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,path):
  """ __new__(cls: type,path: str) """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Exists=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the directory exists.



Get: Exists(self: DirectoryInfo) -> bool



"""

 FullName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: FullName(self: DirectoryInfo) -> str



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the name of this System.IO.DirectoryInfo instance.



Get: Name(self: DirectoryInfo) -> str



"""

 Parent=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the parent directory of a specified subdirectory.



Get: Parent(self: DirectoryInfo) -> DirectoryInfo



"""

 Root=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the root portion of a path.



Get: Root(self: DirectoryInfo) -> DirectoryInfo



"""


 FullPath=None
 OriginalPath=None




class ExtensibleClassFactory(object):
 """ Enables customization of managed objects that extend from unmanaged objects during creation. """
 @staticmethod
 def RegisterObjectCreationCallback(callback):
  """
  RegisterObjectCreationCallback(callback: ObjectCreationDelegate)

   Registers a delegate that is called when an instance of a managed type,that extends from an 

    unmanaged type,needs to allocate the aggregated unmanaged object.

  

  

   callback: A delegate that is called in place of CoCreateInstance.
  """
  pass



class ProcessThreadCollection(ReadOnlyCollectionBase,ICollection,IEnumerable):
 """
 Provides a strongly typed collection of System.Diagnostics.ProcessThread objects.

 

 ProcessThreadCollection(processThreads: Array[ProcessThread])
 """
 def Add(self,thread):
  """
  Add(self: ProcessThreadCollection,thread: ProcessThread) -> int

  

   Appends a process thread to the collection.

  

   thread: The thread to add to the collection.

   Returns: The zero-based index of the thread in the collection.
  """
  pass
 def Contains(self,thread):
  """
  Contains(self: ProcessThreadCollection,thread: ProcessThread) -> bool

  

   Determines whether the specified process thread exists in the collection.

  

   thread: A System.Diagnostics.ProcessThread instance that indicates the thread to find in this collection.

   Returns: true if the thread exists in the collection; otherwise,false.
  """
  pass
 def CopyTo(self,array,index):
  """
  CopyTo(self: ProcessThreadCollection,array: Array[ProcessThread],index: int)

   Copies an array of System.Diagnostics.ProcessThread instances to the collection,at the 

    specified index.

  

  

   array: An array of System.Diagnostics.ProcessThread instances to add to the collection.

   index: The location at which to add the new instances.
  """
  pass
 def IndexOf(self,thread):
  """
  IndexOf(self: ProcessThreadCollection,thread: ProcessThread) -> int

  

   Provides the location of a specified thread within the collection.

  

   thread: The System.Diagnostics.ProcessThread whose index is retrieved.

   Returns: The zero-based index that defines the location of the thread within the 

    System.Diagnostics.ProcessThreadCollection.
  """
  pass
 def Insert(self,index,thread):
  """
  Insert(self: ProcessThreadCollection,index: int,thread: ProcessThread)

   Inserts a process thread at the specified location in the collection.

  

   index: The zero-based index indicating the location at which to insert the thread.

   thread: The thread to insert into the collection.
  """
  pass
 def Remove(self,thread):
  """
  Remove(self: ProcessThreadCollection,thread: ProcessThread)

   Deletes a process thread from the collection.

  

   thread: The thread to remove from the collection.
  """
  pass
 def __add__(self,*args):
  """ x.__add__(y) <==> x+y """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 @staticmethod
 def __new__(self,processThreads):
  """
  __new__(cls: type)

  __new__(cls: type,processThreads: Array[ProcessThread])
  """
  pass
 InnerList=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of elements contained in the System.Collections.ReadOnlyCollectionBase instance.



"""





class StackFrame(object):
 """
 Provides information about a System.Diagnostics.StackFrame,which represents a function call on the call stack for the current thread.

 

 StackFrame()

 StackFrame(fNeedFileInfo: bool)

 StackFrame(skipFrames: int)

 StackFrame(skipFrames: int,fNeedFileInfo: bool)

 StackFrame(fileName: str,lineNumber: int)

 StackFrame(fileName: str,lineNumber: int,colNumber: int)
 """
 def GetFileColumnNumber(self):
  """
  GetFileColumnNumber(self: StackFrame) -> int

  

   Gets the column number in the file that contains the code that is executing. This information is 

    typically extracted from the debugging symbols for the executable.

  

   Returns: The file column number,or 0 (zero) if the file column number cannot be determined.
  """
  pass
 def GetFileLineNumber(self):
  """
  GetFileLineNumber(self: StackFrame) -> int

  

   Gets the line number in the file that contains the code that is executing. This information is 

    typically extracted from the debugging symbols for the executable.

  

   Returns: The file line number,or 0 (zero) if the file line number cannot be determined.
  """
  pass
 def GetFileName(self):
  """
  GetFileName(self: StackFrame) -> str

  

   Gets the file name that contains the code that is executing. This information is typically 

    extracted from the debugging symbols for the executable.

  

   Returns: The file name,or null if the file name cannot be determined.
  """
  pass
 def GetILOffset(self):
  """
  GetILOffset(self: StackFrame) -> int

  

   Gets the offset from the start of the Microsoft intermediate language (MSIL) code for the method 

    that is executing. This offset might be an approximation depending on whether or not the 

    just-in-time (JIT) compiler is generating debugging code. The generation of this debugging 

    information is controlled by the System.Diagnostics.DebuggableAttribute.

  

   Returns: The offset from the start of the MSIL code for the method that is executing.
  """
  pass
 def GetMethod(self):
  """
  GetMethod(self: StackFrame) -> MethodBase

  

   Gets the method in which the frame is executing.

   Returns: The method in which the frame is executing.
  """
  pass
 def GetNativeOffset(self):
  """
  GetNativeOffset(self: StackFrame) -> int

  

   Gets the offset from the start of the native just-in-time (JIT)-compiled code for the method 

    that is being executed. The generation of this debugging information is controlled by the 

    System.Diagnostics.DebuggableAttribute class.

  

   Returns: The offset from the start of the JIT-compiled code for the method that is being executed.
  """
  pass
 def ToString(self):
  """
  ToString(self: StackFrame) -> str

  

   Builds a readable representation of the stack trace.

   Returns: A readable representation of the stack trace.
  """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,fNeedFileInfo: bool)

  __new__(cls: type,skipFrames: int)

  __new__(cls: type,skipFrames: int,fNeedFileInfo: bool)

  __new__(cls: type,fileName: str,lineNumber: int)

  __new__(cls: type,fileName: str,lineNumber: int,colNumber: int)
  """
  pass
 OFFSET_UNKNOWN=-1




class ScrollEventArgs(RoutedEventArgs):
 """
 Provides data for a System.Windows.Controls.Primitives.ScrollBar.Scroll event that occurs when the System.Windows.Controls.Primitives.Thumb of a System.Windows.Controls.Primitives.ScrollBar moves.

 

 ScrollEventArgs(scrollEventType: ScrollEventType,newValue: float)
 """
 @staticmethod
 def __new__(self,scrollEventType,newValue):
  """ __new__(cls: type,scrollEventType: ScrollEventType,newValue: float) """
  pass
 NewValue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that represents the new location of the System.Windows.Controls.Primitives.Thumb in the System.Windows.Controls.Primitives.ScrollBar.



Get: NewValue(self: ScrollEventArgs) -> float



"""

 ScrollEventType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Controls.Primitives.ScrollEventType enumeration value that describes the change in the System.Windows.Controls.Primitives.Thumb position that caused this event.



Get: ScrollEventType(self: ScrollEventArgs) -> ScrollEventType



"""





class ProcessPriorityClass(Enum,IComparable,IFormattable,IConvertible):
 """
 Indicates the priority that the system associates with a process. This value,together with the priority value of each thread of the process,determines each thread's base priority level.

 

 enum ProcessPriorityClass,values: AboveNormal (32768),BelowNormal (16384),High (128),Idle (64),Normal (32),RealTime (256)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AboveNormal=None
 BelowNormal=None
 High=None
 Idle=None
 Normal=None
 RealTime=None
 value__=None




class IComponent(IDisposable):
 """ Provides functionality required by all components. """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 Site=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the System.ComponentModel.ISite associated with the System.ComponentModel.IComponent.



Get: Site(self: IComponent) -> ISite



Set: Site(self: IComponent)=value

"""


 Disposed=None




"""
Consolidate all imports and resources for other forms based classes to use.

"""  #

import sys

from abc import ABCMeta

import clr

import os.path as op
from pyrevit.compat import PY3, PY2
import pyrevit.engine as eng

# WPF/Form Imports
clr.AddReference("PresentationFramework")  # System.Windows: Controls, ?
clr.AddReference("WindowsBase")            # System.Windows.Input
clr.AddReference("System.Drawing")         # FontFamily
clr.AddReference('System.Windows.Forms') # Forms

import System.Windows
from System.Windows import Window
from System.IO import StringReader

# Console
from System.Environment import Exit, NewLine
from System.Drawing import FontFamily
from System.Windows.Input import Key

# FlexForm Imports
from System.Windows import Controls, Window
from System.Windows import HorizontalAlignment, VerticalAlignment, Thickness

# OS Dialogs
from System.Windows import Forms


ASSEMBLY_FILE_TYPE = 'dll'
ASSEMBLY_FILE_EXT = '.dll'

ipy_assmname = '{prefix}IronPython'.format(prefix=eng.EnginePrefix)
ipy_dllpath = op.join(eng.EnginePath, ipy_assmname + ASSEMBLY_FILE_EXT)
if PY3:
    clr.AddReference(ipy_dllpath)
else:
    clr.AddReferenceToFileAndPath(ipy_dllpath)

import IronPython

# WPF
wpf = None
wpf_assmname = '{prefix}IronPython.Wpf'.format(prefix=eng.EnginePrefix)
wpf_dllpath = op.join(eng.EnginePath, wpf_assmname + ASSEMBLY_FILE_EXT)
try:
    clr.AddReference(wpf_assmname)
    if PY3:
        wpf = IronPython.Modules.Wpf
    else:
        import wpf
except Exception:
    clr.AddReferenceToFileAndPath(wpf_dllpath)
    import wpf


class AnchorStyles(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies how a control anchors to the edges of its container.

 

 enum (flags) AnchorStyles,values: Bottom (2),Left (4),None (0),Right (8),Top (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Bottom=None
 Left=None
 None=None
 Right=None
 Top=None
 value__=None




class SecurityProtocolType(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the security protocols that are supported by the Schannel security package.

 

 enum (flags) SecurityProtocolType,values: Ssl3 (48),SystemDefault (0),Tls (192),Tls11 (768),Tls12 (3072)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Ssl3=None
 SystemDefault=None
 Tls=None
 Tls11=None
 Tls12=None
 value__=None




# encoding: utf-8
# module System.Windows.Resources calls itself Resources
# from PresentationCore,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class AssemblyAssociatedContentFileAttribute(Attribute,_Attribute):
 """
 This attribute is interpreted during the Extensible Application Markup Language (XAML) compilation process to associate loose content with a Windows Presentation Foundation (WPF) application.

 

 AssemblyAssociatedContentFileAttribute(relativeContentFilePath: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,relativeContentFilePath):
  """ __new__(cls: type,relativeContentFilePath: str) """
  pass
 RelativeContentFilePath=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the path to the associated content.



Get: RelativeContentFilePath(self: AssemblyAssociatedContentFileAttribute) -> str



"""






class CommonAce(QualifiedAce):
 """
 Represents an access control entry (ACE).

 

 CommonAce(flags: AceFlags,qualifier: AceQualifier,accessMask: int,sid: SecurityIdentifier,isCallback: bool,opaque: Array[Byte])
 """
 def GetBinaryForm(self,binaryForm,offset):
  """
  GetBinaryForm(self: CommonAce,binaryForm: Array[Byte],offset: int)

   Marshals the contents of the System.Security.AccessControl.CommonAce object into the specified 

    byte array beginning at the specified offset.

  

  

   binaryForm: The byte array into which the contents of the System.Security.AccessControl.CommonAce object is 

    marshaled.

  

   offset: The offset at which to start marshaling.
  """
  pass
 @staticmethod
 def MaxOpaqueLength(isCallback):
  """
  MaxOpaqueLength(isCallback: bool) -> int

  

   Gets the maximum allowed length of an opaque data BLOB for callback access control entries 

    (ACEs).

  

  

   isCallback: true to specify that the System.Security.AccessControl.CommonAce object is a callback ACE type.

   Returns: The allowed length of an opaque data BLOB.
  """
  pass
 @staticmethod
 def __new__(self,flags,qualifier,accessMask,sid,isCallback,opaque):
  """ __new__(cls: type,flags: AceFlags,qualifier: AceQualifier,accessMask: int,sid: SecurityIdentifier,isCallback: bool,opaque: Array[Byte]) """
  pass
 BinaryLength=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the length,in bytes,of the binary representation of the current System.Security.AccessControl.CommonAce object. Use this length with the System.Security.AccessControl.CommonAce.GetBinaryForm(System.Byte[],System.Int32) method before marshaling the ACL into a binary array.



Get: BinaryLength(self: CommonAce) -> int



"""





class DateTimeOffsetConverter(TypeConverter):
 """
 Provides a type converter to convert System.DateTimeOffset structures to and from various other representations.

 

 DateTimeOffsetConverter()
 """
 def CanConvertFrom(self,*__args):
  """
  CanConvertFrom(self: DateTimeOffsetConverter,context: ITypeDescriptorContext,sourceType: Type) -> bool

  

   Returns a value that indicates whether an object of the specified source type can be converted 

    to a System.DateTimeOffset.

  

  

   context: The date format context.

   sourceType: The source type to check.

   Returns: true if the specified type can be converted to a System.DateTimeOffset; otherwise,false.
  """
  pass
 def CanConvertTo(self,*__args):
  """
  CanConvertTo(self: DateTimeOffsetConverter,context: ITypeDescriptorContext,destinationType: Type) -> bool

  

   Returns a value that indicates whether a System.DateTimeOffset can be converted to an object of 

    the specified type.

  

  

   context: The date format context.

   destinationType: The destination type to check.

   Returns: true if a System.DateTimeOffset can be converted to the specified type; otherwise,false.
  """
  pass
 def ConvertFrom(self,*__args):
  """
  ConvertFrom(self: DateTimeOffsetConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object) -> object

  

   Converts the specified object to a System.DateTimeOffset.

  

   context: The date format context.

   culture: The date culture.

   value: The object to be converted.

   Returns: A System.DateTimeOffset that represents the specified object.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: DateTimeOffsetConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object,destinationType: Type) -> object

  

   Converts a System.DateTimeOffset to an object of the specified type.

  

   context: The date format context.

   culture: The date culture.

   value: The System.DateTimeOffset to be converted.

   destinationType: The type to convert to.

   Returns: An object of the specified type that represents the System.DateTimeOffset.
  """
  pass



class UpDownEventArgs(EventArgs):
 """
 Provides data for controls that derive from the System.Windows.Forms.UpDownBase control.

 

 UpDownEventArgs(buttonPushed: int)
 """
 @staticmethod
 def __new__(self,buttonPushed):
  """ __new__(cls: type,buttonPushed: int) """
  pass
 ButtonID=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that represents which button the user clicked.



Get: ButtonID(self: UpDownEventArgs) -> int



"""





class EventWaitHandleAccessRule(AccessRule):
 """
 Represents a set of access rights allowed or denied for a user or group. This class cannot be inherited.

 

 EventWaitHandleAccessRule(identity: IdentityReference,eventRights: EventWaitHandleRights,type: AccessControlType)

 EventWaitHandleAccessRule(identity: str,eventRights: EventWaitHandleRights,type: AccessControlType)
 """
 @staticmethod
 def __new__(self,identity,eventRights,type):
  """
  __new__(cls: type,identity: IdentityReference,eventRights: EventWaitHandleRights,type: AccessControlType)

  __new__(cls: type,identity: str,eventRights: EventWaitHandleRights,type: AccessControlType)
  """
  pass
 AccessMask=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the access mask for this rule.



"""

 EventWaitHandleRights=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the rights allowed or denied by the access rule.



Get: EventWaitHandleRights(self: EventWaitHandleAccessRule) -> EventWaitHandleRights



"""





class Help(object):
 """ Encapsulates the HTML Help 1.0 engine. """
 @staticmethod
 def ShowHelp(parent,url,*__args):
  """
  ShowHelp(parent: Control,url: str,keyword: str)

   Displays the contents of the Help file found at the specified URL for a specific keyword.

  

   parent: A System.Windows.Forms.Control that identifies the parent of the Help dialog box.

   url: The path and name of the Help file.

   keyword: The keyword to display Help for.

  ShowHelp(parent: Control,url: str,command: HelpNavigator,parameter: object)

   Displays the contents of the Help file located at the URL supplied by the user.

  

   parent: A System.Windows.Forms.Control that identifies the parent of the Help dialog box.

   url: The path and name of the Help file.

   command: One of the System.Windows.Forms.HelpNavigator values.

   parameter: A string that contains the topic identifier.

  ShowHelp(parent: Control,url: str)

   Displays the contents of the Help file at the specified URL.

  

   parent: A System.Windows.Forms.Control that identifies the parent of the Help dialog box.

   url: The path and name of the Help file.

  ShowHelp(parent: Control,url: str,navigator: HelpNavigator)

   Displays the contents of the Help file found at the specified URL for a specific topic.

  

   parent: A System.Windows.Forms.Control that identifies the parent of the Help dialog box.

   url: The path and name of the Help file.

   navigator: One of the System.Windows.Forms.HelpNavigator values.
  """
  pass
 @staticmethod
 def ShowHelpIndex(parent,url):
  """
  ShowHelpIndex(parent: Control,url: str)

   Displays the index of the specified Help file.

  

   parent: A System.Windows.Forms.Control that identifies the parent of the Help dialog box.

   url: The path and name of the Help file.
  """
  pass
 @staticmethod
 def ShowPopup(parent,caption,location):
  """
  ShowPopup(parent: Control,caption: str,location: Point)

   Displays a Help pop-up window.

  

   parent: A System.Windows.Forms.Control that identifies the parent of the Help dialog box.

   caption: The message to display in the pop-up window.

   location: A value that specifies the horizontal and vertical coordinates at which to display the pop-up 

    window,relative to the upper-left corner of the screen.
  """
  pass



class DataGridCell(object):
 """
 Identifies a cell in the grid.

 

 DataGridCell(r: int,c: int)
 """
 def Equals(self,o):
  """
  Equals(self: DataGridCell,o: object) -> bool

  

   Gets a value indicating whether the System.Windows.Forms.DataGridCell is identical to a second 

    System.Windows.Forms.DataGridCell.

  

  

   o: An object you are to comparing.

   Returns: true if the second object is identical to the first; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: DataGridCell) -> int

  

   Gets a hash value that can be added to a System.Collections.Hashtable.

   Returns: A number that uniquely identifies the System.Windows.Forms.DataGridCell in a 

    System.Collections.Hashtable.
  """
  pass
 def ToString(self):
  """
  ToString(self: DataGridCell) -> str

  

   Gets the row number and column number of the cell.

   Returns: A string containing the row number and column number.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 @staticmethod
 def __new__(self,r,c):
  """
  __new__(cls: type,r: int,c: int)

  __new__[DataGridCell]() -> DataGridCell
  """
  pass
 def __ne__(self,*args):
  pass
 ColumnNumber=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the number of a column in the System.Windows.Forms.DataGrid control.



Get: ColumnNumber(self: DataGridCell) -> int



Set: ColumnNumber(self: DataGridCell)=value

"""

 RowNumber=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the number of a row in the System.Windows.Forms.DataGrid control.



Get: RowNumber(self: DataGridCell) -> int



Set: RowNumber(self: DataGridCell)=value

"""





class HttpListenerTimeoutManager(object):
 # no doc
 DrainEntityBody=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: DrainEntityBody(self: HttpListenerTimeoutManager) -> TimeSpan



Set: DrainEntityBody(self: HttpListenerTimeoutManager)=value

"""

 EntityBody=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: EntityBody(self: HttpListenerTimeoutManager) -> TimeSpan



Set: EntityBody(self: HttpListenerTimeoutManager)=value

"""

 HeaderWait=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: HeaderWait(self: HttpListenerTimeoutManager) -> TimeSpan



Set: HeaderWait(self: HttpListenerTimeoutManager)=value

"""

 IdleConnection=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: IdleConnection(self: HttpListenerTimeoutManager) -> TimeSpan



Set: IdleConnection(self: HttpListenerTimeoutManager)=value

"""

 MinSendBytesPerSecond=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: MinSendBytesPerSecond(self: HttpListenerTimeoutManager) -> Int64



Set: MinSendBytesPerSecond(self: HttpListenerTimeoutManager)=value

"""

 RequestQueue=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Get: RequestQueue(self: HttpListenerTimeoutManager) -> TimeSpan



Set: RequestQueue(self: HttpListenerTimeoutManager)=value

"""





class Screen(object):
 """ Represents a display device or multiple display devices on a single system. """
 def Equals(self,obj):
  """
  Equals(self: Screen,obj: object) -> bool

  

   Gets or sets a value indicating whether the specified object is equal to this Screen.

  

   obj: The object to compare to this System.Windows.Forms.Screen.

   Returns: true if the specified object is equal to this System.Windows.Forms.Screen; otherwise,false.
  """
  pass
 @staticmethod
 def FromControl(control):
  """
  FromControl(control: Control) -> Screen

  

   Retrieves a System.Windows.Forms.Screen for the display that contains the largest portion of the 

    specified control.

  

  

   control: A System.Windows.Forms.Control for which to retrieve a System.Windows.Forms.Screen.

   Returns: A System.Windows.Forms.Screen for the display that contains the largest region of the specified 

    control. In multiple display environments where no display contains the control,the display 

    closest to the specified control is returned.
  """
  pass
 @staticmethod
 def FromHandle(hwnd):
  """
  FromHandle(hwnd: IntPtr) -> Screen

  

   Retrieves a System.Windows.Forms.Screen for the display that contains the largest portion of the 

    object referred to by the specified handle.

  

  

   hwnd: The window handle for which to retrieve the System.Windows.Forms.Screen.

   Returns: A System.Windows.Forms.Screen for the display that contains the largest region of the object. In 

    multiple display environments where no display contains any portion of the specified window,the 

    display closest to the object is returned.
  """
  pass
 @staticmethod
 def FromPoint(point):
  """
  FromPoint(point: Point) -> Screen

  

   Retrieves a System.Windows.Forms.Screen for the display that contains the specified point.

  

   point: A System.Drawing.Point that specifies the location for which to retrieve a 

    System.Windows.Forms.Screen.

  

   Returns: A System.Windows.Forms.Screen for the display that contains the point. In multiple display 

    environments where no display contains the point,the display closest to the specified point is 

    returned.
  """
  pass
 @staticmethod
 def FromRectangle(rect):
  """
  FromRectangle(rect: Rectangle) -> Screen

  

   Retrieves a System.Windows.Forms.Screen for the display that contains the largest portion of the 

    rectangle.

  

  

   rect: A System.Drawing.Rectangle that specifies the area for which to retrieve the display.

   Returns: A System.Windows.Forms.Screen for the display that contains the largest region of the specified 

    rectangle. In multiple display environments where no display contains the rectangle,the display 

    closest to the rectangle is returned.
  """
  pass
 @staticmethod
 def GetBounds(*__args):
  """
  GetBounds(ctl: Control) -> Rectangle

  

   Retrieves the bounds of the display that contains the largest portion of the specified control.

  

   ctl: The System.Windows.Forms.Control for which to retrieve the display bounds.

   Returns: A System.Drawing.Rectangle that specifies the bounds of the display that contains the specified 

    control. In multiple display environments where no display contains the specified control,the 

    display closest to the control is returned.

  

  GetBounds(rect: Rectangle) -> Rectangle

  

   Retrieves the bounds of the display that contains the largest portion of the specified rectangle.

  

   rect: A System.Drawing.Rectangle that specifies the area for which to retrieve the display bounds.

   Returns: A System.Drawing.Rectangle that specifies the bounds of the display that contains the specified 

    rectangle. In multiple display environments where no monitor contains the specified rectangle,

    the monitor closest to the rectangle is returned.

  

  GetBounds(pt: Point) -> Rectangle

  

   Retrieves the bounds of the display that contains the specified point.

  

   pt: A System.Drawing.Point that specifies the coordinates for which to retrieve the display bounds.

   Returns: A System.Drawing.Rectangle that specifies the bounds of the display that contains the specified 

    point. In multiple display environments where no display contains the specified point,the 

    display closest to the point is returned.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: Screen) -> int

  

   Computes and retrieves a hash code for an object.

   Returns: A hash code for an object.
  """
  pass
 @staticmethod
 def GetWorkingArea(*__args):
  """
  GetWorkingArea(ctl: Control) -> Rectangle

  

   Retrieves the working area for the display that contains the largest region of the specified 

    control. The working area is the desktop area of the display,excluding taskbars,docked 

    windows,and docked tool bars.

  

  

   ctl: The System.Windows.Forms.Control for which to retrieve the working area.

   Returns: A System.Drawing.Rectangle that specifies the working area. In multiple display environments 

    where no display contains the specified control,the display closest to the control is returned.

  

  GetWorkingArea(rect: Rectangle) -> Rectangle

  

   Retrieves the working area for the display that contains the largest portion of the specified 

    rectangle. The working area is the desktop area of the display,excluding taskbars,docked 

    windows,and docked tool bars.

  

  

   rect: The System.Drawing.Rectangle that specifies the area for which to retrieve the working area.

   Returns: A System.Drawing.Rectangle that specifies the working area. In multiple display environments 

    where no display contains the specified rectangle,the display closest to the rectangle is 

    returned.

  

  GetWorkingArea(pt: Point) -> Rectangle

  

   Retrieves the working area closest to the specified point. The working area is the desktop area 

    of the display,excluding taskbars,docked windows,and docked tool bars.

  

  

   pt: A System.Drawing.Point that specifies the coordinates for which to retrieve the working area.

   Returns: A System.Drawing.Rectangle that specifies the working area. In multiple display environments 

    where no display contains the specified point,the display closest to the point is returned.
  """
  pass
 def ToString(self):
  """
  ToString(self: Screen) -> str

  

   Retrieves a string representing this object.

   Returns: A string representation of the object.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __ne__(self,*args):
  pass
 BitsPerPixel=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the number of bits of memory,associated with one pixel of data.



Get: BitsPerPixel(self: Screen) -> int



"""

 Bounds=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the bounds of the display.



Get: Bounds(self: Screen) -> Rectangle



"""

 DeviceName=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the device name associated with a display.



Get: DeviceName(self: Screen) -> str



"""

 Primary=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether a particular display is the primary device.



Get: Primary(self: Screen) -> bool



"""

 WorkingArea=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the working area of the display. The working area is the desktop area of the display,excluding taskbars,docked windows,and docked tool bars.



Get: WorkingArea(self: Screen) -> Rectangle



"""


 AllScreens=None
 PrimaryScreen=None




from typing import Tuple, Set, Iterable, List


class ApplicationEntryPoint(UIApplication):
    def __init__(self): ...
    def Initialize(self, obj: Object, addinFolder: str) -> None: ...
    def FinishInitializationEO(self) -> None: ...
    def OnShutdownEO(self) -> None: ...
    @property
    def AddinFolder(self) -> str: ...
    def CreateRibbonTab(self, tabName: str) -> None: ...
    @overload
    def CreateRibbonPanel(self, tab: Tab, panelName: str) -> RibbonPanel: ...
    @overload
    def CreateRibbonPanel(self, panelName: str) -> RibbonPanel: ...
    @overload
    def CreateRibbonPanel(self, tabName: str, panelName: str) -> RibbonPanel: ...
    @overload
    def GetRibbonPanels(self, tabName: str) -> List: ...
    @overload
    def GetRibbonPanels(self, tab: Tab) -> List: ...
    @overload
    def GetRibbonPanels(self) -> List: ...


class DocumentEntryPoint(UIDocument):
    def __init__(self): ...
    def Initialize(self, obj: Object, addinFolder: str) -> None: ...
    def FinishInitializationEO(self) -> None: ...
    def OnShutdownEO(self) -> None: ...
    @property
    def AddinFolder(self) -> str: ...



class HelpNavigator(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies constants indicating which elements of the Help file to display.

 

 enum HelpNavigator,values: AssociateIndex (-2147483643),Find (-2147483644),Index (-2147483645),KeywordIndex (-2147483642),TableOfContents (-2147483646),Topic (-2147483647),TopicId (-2147483641)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 AssociateIndex=None
 Find=None
 Index=None
 KeywordIndex=None
 TableOfContents=None
 Topic=None
 TopicId=None
 value__=None




# encoding: utf-8
# module System.Diagnostics.CodeAnalysis calls itself CodeAnalysis
# from mscorlib,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089,System,Version=4.0.0.0,Culture=neutral,PublicKeyToken=b77a5c561934e089
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class ExcludeFromCodeCoverageAttribute(Attribute,_Attribute):
 """
 Specifies that the attributed code should be excluded from code coverage information.

 

 ExcludeFromCodeCoverageAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass

class SuppressMessageAttribute(Attribute,_Attribute):
 """
 Suppresses reporting of a specific static analysis tool rule violation,allowing multiple suppressions on a single code artifact.

 

 SuppressMessageAttribute(category: str,checkId: str)
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,category,checkId):
  """ __new__(cls: type,category: str,checkId: str) """
  pass
 Category=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the category identifying the classification of the attribute.



Get: Category(self: SuppressMessageAttribute) -> str



"""

 CheckId=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the identifier of the static analysis tool rule to be suppressed.



Get: CheckId(self: SuppressMessageAttribute) -> str



"""

 Justification=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the justification for suppressing the code analysis message.



Get: Justification(self: SuppressMessageAttribute) -> str



Set: Justification(self: SuppressMessageAttribute)=value

"""

 MessageId=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets an optional argument expanding on exclusion criteria.



Get: MessageId(self: SuppressMessageAttribute) -> str



Set: MessageId(self: SuppressMessageAttribute)=value

"""

 Scope=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the scope of the code that is relevant for the attribute.



Get: Scope(self: SuppressMessageAttribute) -> str



Set: Scope(self: SuppressMessageAttribute)=value

"""

 Target=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a fully qualified path that represents the target of the attribute.



Get: Target(self: SuppressMessageAttribute) -> str



Set: Target(self: SuppressMessageAttribute)=value

"""






class DataGridViewAutoSizeModeEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.DataGridViewSystem.Windows.Forms.DataGridView.AutoSizeRowsModeChanged and System.Windows.Forms.DataGridView.RowHeadersWidthSizeModeChanged events.

 

 DataGridViewAutoSizeModeEventArgs(previousModeAutoSized: bool)
 """
 @staticmethod
 def __new__(self,previousModeAutoSized):
  """ __new__(cls: type,previousModeAutoSized: bool) """
  pass
 PreviousModeAutoSized=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value specifying whether the System.Windows.Forms.DataGridView was previously set to automatically resize.



Get: PreviousModeAutoSized(self: DataGridViewAutoSizeModeEventArgs) -> bool



"""





class LinkClickedEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Forms.RichTextBox.LinkClicked event.

 

 LinkClickedEventArgs(linkText: str)
 """
 @staticmethod
 def __new__(self,linkText):
  """ __new__(cls: type,linkText: str) """
  pass
 LinkText=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the text of the link being clicked.



Get: LinkText(self: LinkClickedEventArgs) -> str



"""





class Border3DStyle(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the style of a three-dimensional border.

 

 enum Border3DStyle,values: Adjust (8192),Bump (9),Etched (6),Flat (16394),Raised (5),RaisedInner (4),RaisedOuter (1),Sunken (10),SunkenInner (8),SunkenOuter (2)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Adjust=None
 Bump=None
 Etched=None
 Flat=None
 Raised=None
 RaisedInner=None
 RaisedOuter=None
 Sunken=None
 SunkenInner=None
 SunkenOuter=None
 value__=None




class IItemContainerGenerator:
 """ An interface that is implemented by classes which are responsible for generating user interface (UI) content on behalf of a host. """
 def GenerateNext(self,isNewlyRealized=None):
  """
  GenerateNext(self: IItemContainerGenerator) -> (DependencyObject,bool)

  

   Returns the container element used to display the next item,and whether the container element 

    has been newly generated (realized).

  

   Returns: A System.Windows.DependencyObject that is the container element which is used to display the 

    next item.

  

  GenerateNext(self: IItemContainerGenerator) -> DependencyObject

  

   Returns the container element used to display the next item.

   Returns: A System.Windows.DependencyObject that is the container element which is used to display the 

    next item.
  """
  pass
 def GeneratorPositionFromIndex(self,itemIndex):
  """
  GeneratorPositionFromIndex(self: IItemContainerGenerator,itemIndex: int) -> GeneratorPosition

  

   Returns the System.Windows.Controls.Primitives.GeneratorPosition object that maps to the item at 

    the specified index.

  

  

   itemIndex: The index of desired item.

   Returns: An System.Windows.Controls.Primitives.GeneratorPosition object that maps to the item at the 

    specified index.
  """
  pass
 def GetItemContainerGeneratorForPanel(self,panel):
  """
  GetItemContainerGeneratorForPanel(self: IItemContainerGenerator,panel: Panel) -> ItemContainerGenerator

  

   Returns the System.Windows.Controls.ItemContainerGenerator appropriate for use by the specified 

    panel.

  

  

   panel: The panel for which to return an appropriate System.Windows.Controls.ItemContainerGenerator.

   Returns: An System.Windows.Controls.ItemContainerGenerator appropriate for use by the specified panel.
  """
  pass
 def IndexFromGeneratorPosition(self,position):
  """
  IndexFromGeneratorPosition(self: IItemContainerGenerator,position: GeneratorPosition) -> int

  

   Returns the index that maps to the specified 

    System.Windows.Controls.Primitives.GeneratorPosition.

  

  

   position: The index of desired item.The System.Windows.Controls.Primitives.GeneratorPosition  for the 

    desired index.

  

   Returns: An System.Int32 that is the index which maps to the specified 

    System.Windows.Controls.Primitives.GeneratorPosition.
  """
  pass
 def PrepareItemContainer(self,container):
  """
  PrepareItemContainer(self: IItemContainerGenerator,container: DependencyObject)

   Prepares the specified element as the container for the corresponding item.

  

   container: The container to prepare. Normally,container is the result of the previous call to 

    erload:System.Windows.Controls.Primitives.IItemContainerGenerator.GenerateNext.
  """
  pass
 def Remove(self,position,count):
  """
  Remove(self: IItemContainerGenerator,position: GeneratorPosition,count: int)

   Removes one or more generated (realized) items.

  

   position: The System.Int32 index of the element to remove. position must refer to a previously generated 

    (realized) item,which means its offset must be zero.

  

   count: The System.Int32 number of elements to remove,starting at position.
  """
  pass
 def RemoveAll(self):
  """
  RemoveAll(self: IItemContainerGenerator)

   Removes all generated (realized) items.
  """
  pass
 def StartAt(self,position,direction,allowStartAtRealizedItem=None):
  """
  StartAt(self: IItemContainerGenerator,position: GeneratorPosition,direction: GeneratorDirection,allowStartAtRealizedItem: bool) -> IDisposable

  

   Prepares the generator to generate items,starting at the specified 

    System.Windows.Controls.Primitives.GeneratorPosition,and in the specified 

    System.Windows.Controls.Primitives.GeneratorDirection,and controlling whether or not to start 

    at a generated (realized) item.

  

  

   position: A System.Windows.Controls.Primitives.GeneratorPosition,that specifies the position of the item 

    to start generating items at.

  

   direction: Specifies the position of the item to start generating items at.

   allowStartAtRealizedItem: A System.Boolean that specifies whether to start at a generated (realized) item.

   Returns: An System.IDisposable object that tracks the lifetime of the generation process.

  StartAt(self: IItemContainerGenerator,position: GeneratorPosition,direction: GeneratorDirection) -> IDisposable

  

   Prepares the generator to generate items,starting at the specified 

    System.Windows.Controls.Primitives.GeneratorPosition,and in the specified 

    System.Windows.Controls.Primitives.GeneratorDirection.

  

  

   position: A System.Windows.Controls.Primitives.GeneratorPosition,that specifies the position of the item 

    to start generating items at.

  

   direction: A System.Windows.Controls.Primitives.GeneratorDirection that specifies the direction which to 

    generate items.

  

   Returns: An System.IDisposable object that tracks the lifetime of the generation process.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class UCOMIPersistFile:
 """ Use System.Runtime.InteropServices.ComTypes.IPersistFile instead. """
 def GetClassID(self,pClassID):
  """
  GetClassID(self: UCOMIPersistFile) -> Guid

  

   Retrieves the class identifier (CLSID) of an object.
  """
  pass
 def GetCurFile(self,ppszFileName):
  """
  GetCurFile(self: UCOMIPersistFile) -> str

  

   Retrieves either the absolute path to current working file of the object,or if there is no 

    current working file,the default filename prompt of the object.
  """
  pass
 def IsDirty(self):
  """
  IsDirty(self: UCOMIPersistFile) -> int

  

   Checks an object for changes since it was last saved to its current file.

   Returns: S_OK if the file has changed since it was last saved; S_FALSE if the file has not changed since 

    it was last saved.
  """
  pass
 def Load(self,pszFileName,dwMode):
  """
  Load(self: UCOMIPersistFile,pszFileName: str,dwMode: int)

   Opens the specified file and initializes an object from the file contents.

  

   pszFileName: A zero-terminated string containing the absolute path of the file to open.

   dwMode: A combination of values from the STGM enumeration to indicate the access mode in which to open 

    pszFileName.
  """
  pass
 def Save(self,pszFileName,fRemember):
  """
  Save(self: UCOMIPersistFile,pszFileName: str,fRemember: bool)

   Saves a copy of the object into the specified file.

  

   pszFileName: A zero-terminated string containing the absolute path of the file to which the object is saved.

   fRemember: Indicates whether pszFileName is to be used as the current working file.
  """
  pass
 def SaveCompleted(self,pszFileName):
  """
  SaveCompleted(self: UCOMIPersistFile,pszFileName: str)

   Notifies the object that it can write to its file.

  

   pszFileName: The absolute path of the file where the object was previously saved.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class OpenReadCompletedEventArgs(AsyncCompletedEventArgs):
 """ Provides data for the System.Net.WebClient.OpenReadCompleted event. """
 Result=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a readable stream that contains data downloaded by a erload:System.Net.WebClient.DownloadDataAsync method.



Get: Result(self: OpenReadCompletedEventArgs) -> Stream



"""





class MTAThreadAttribute(Attribute,_Attribute):
 """
 Indicates that the COM threading model for an application is multithreaded apartment (MTA).

 

 MTAThreadAttribute()
 """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



# encoding: utf-8
# module System.Windows.Media.Converters calls itself Converters
# from PresentationCore,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class BaseIListConverter(TypeConverter):
 """ Defines methods used to convert System.Collections.IList collection members to and from instances of System.String. """
 def CanConvertFrom(self,*__args):
  """
  CanConvertFrom(self: BaseIListConverter,td: ITypeDescriptorContext,t: Type) -> bool

  

   Determines if a given type can be converted.

  

   td: Provides contextual information required for conversion.

   t: Type being evaluated for conversion.

   Returns: true if this type can be converted; otherwise,false.
  """
  pass
 def CanConvertTo(self,*__args):
  """
  CanConvertTo(self: BaseIListConverter,context: ITypeDescriptorContext,destinationType: Type) -> bool

  

   Determines if a given type can be converted to a System.String.

  

   context: Provides contextual information required for conversion.

   destinationType: Type being evaluated for conversion.

   Returns: true if this type can be converted; otherwise,false.
  """
  pass
 def ConvertFrom(self,*__args):
  """
  ConvertFrom(self: BaseIListConverter,td: ITypeDescriptorContext,ci: CultureInfo,value: object) -> object

  

   Converts a System.String to a supported instance of System.Collections.IList.

  

   td: Provides contextual information required for conversion.

   ci: Cultural information to respect during conversion.

   value: String used for conversion.

   Returns: An System.Object that represents the result of the conversion.
  """
  pass
 def ConvertTo(self,*__args):
  """
  ConvertTo(self: BaseIListConverter,context: ITypeDescriptorContext,culture: CultureInfo,value: object,destinationType: Type) -> object

  

   Converts a supported instance of System.Collections.IList to a System.String.

  

   context: Provides contextual information required for conversion.

   culture: Cultural information to respect during conversion.

   value: Object being evaluated for conversion.

   destinationType: Destination type being evaluated for conversion.

   Returns: String representation of the System.Collections.IList collection.
  """
  pass

class BoolIListConverter(BaseIListConverter):
 """
 Converts the members of an System.Collections.IList collection of Boolean values to and from instances of System.String.

 

 BoolIListConverter()
 """

class BrushValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Brush.

 

 BrushValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: BrushValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of System.Windows.Media.Brush 

    is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: BrushValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Brush can be converted to a System.String.

  

   value: Instance of System.Windows.Media.Brush to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: BrushValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Brush.

  

   value: System.String value to convert into a System.Windows.Media.Brush.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Brush based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: BrushValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Brush to a System.String.

  

   value: Instance of System.Windows.Media.Brush to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Brush object.
  """
  pass

class CacheModeValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.CacheMode.

 

 CacheModeValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: CacheModeValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines whether the specified System.String can be converted to an instance of 

    System.Windows.Media.CacheMode.

  

  

   value: A System.String to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: true if value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: CacheModeValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines whether the specified instance of System.Windows.Media.CacheMode can be converted to 

    a System.String.

  

  

   value: An instance of System.Windows.Media.CacheMode to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: CacheModeValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.CacheMode.

  

   value: A System.String value to convert into a System.Windows.Media.CacheMode.

   context: Context information that is used for conversion.

   Returns: A new instance of System.Windows.Media.CacheMode based on the specified value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: CacheModeValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.CacheMode to a System.String.

  

   value: An instance of System.Windows.Media.CacheMode to evaluate for conversion.

   context: Context information that is used for conversion.

   Returns: A System.String representation of the specified System.Windows.Media.CacheMode object.
  """
  pass

class CharIListConverter(BaseIListConverter):
 """
 Converts the members of an System.Collections.IList collection of Unicode characters to and from instances of System.String.

 

 CharIListConverter()
 """

class DoubleCollectionValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.DoubleCollection.

 

 DoubleCollectionValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: DoubleCollectionValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.DoubleCollection is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: DoubleCollectionValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.DoubleCollection can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.DoubleCollection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: DoubleCollectionValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.DoubleCollection.

  

   value: System.String value to convert into a System.Windows.Media.DoubleCollection.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.DoubleCollection based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: DoubleCollectionValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.DoubleCollection to a System.String.

  

   value: Instance of System.Windows.Media.DoubleCollection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.DoubleCollection object.
  """
  pass

class DoubleIListConverter(BaseIListConverter):
 """
 Converts members of an System.Collections.IList collection containing System.Double numbers to and from instances of System.String.

 

 DoubleIListConverter()
 """

class GeometryValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Geometry.

 

 GeometryValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: GeometryValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Geometry is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: GeometryValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Geometry can be converted to a System.String.

  

   value: Instance of System.Windows.Media.Geometry to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: GeometryValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Geometry.

  

   value: System.String value to convert into a System.Windows.Media.Geometry.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Geometry based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: GeometryValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Geometry to a System.String.

  

   value: Instance of System.Windows.Media.Geometry to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Geometry object.
  """
  pass

class Int32CollectionValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Int32Collection.

 

 Int32CollectionValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: Int32CollectionValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Converts an instance of System.Windows.Media.Int32Collection to a System.String.

  

   value: Instance of System.Windows.Media.Int32Collection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Int32Collection object.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: Int32CollectionValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Converts a System.String into a System.Windows.Media.Int32Collection.

  

   value: System.String value to convert into a System.Windows.Media.Int32Collection.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Int32Collection based on the supplied value.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: Int32CollectionValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Determines if an instance of System.Windows.Media.Int32Collection can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.Int32Collection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: Int32CollectionValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Int32Collection is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass

class PathFigureCollectionValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.PathFigureCollection.

 

 PathFigureCollectionValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: PathFigureCollectionValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.PathFigureCollection is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: PathFigureCollectionValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.PathFigureCollection can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.PathFigureCollection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: PathFigureCollectionValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.PathFigureCollection.

  

   value: System.String value to convert into a System.Windows.Media.PathFigureCollection.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.PathFigureCollection based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: PathFigureCollectionValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.PathFigureCollection to a System.String

  

   value: Instance of System.Windows.Media.PathFigureCollection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.PathFigureCollection object.
  """
  pass

class PointCollectionValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.PointCollection.

 

 PointCollectionValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: PointCollectionValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.PointCollection is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: PointCollectionValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.PointCollection can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.PointCollection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: PointCollectionValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.PointCollection.

  

   value: System.String value to convert into a System.Windows.Media.PointCollection.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.PointCollection based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: PointCollectionValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.PointCollection to a System.String.

  

   value: Instance of System.Windows.Media.PointCollection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.PointCollection object.
  """
  pass

class PointIListConverter(BaseIListConverter):
 """
 Converts an System.Collections.IList collection of System.Windows.Point values to and from instances of System.String.

 

 PointIListConverter()
 """

class TransformValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.Transform.

 

 TransformValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: TransformValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.Transform is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: TransformValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.Transform can be converted to a System.String.

  

   value: Instance of System.Windows.Media.Transform to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: TransformValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.Transform.

  

   value: System.String value to convert into a System.Windows.Media.Transform.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.Transform based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: TransformValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.Transform to a System.String.

  

   value: Instance of System.Windows.Media.Transform to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.Transform object.
  """
  pass

class UShortIListConverter(BaseIListConverter):
 """
 Converts an System.Collections.IList collection of UShort number values to and from instances of System.String.

 

 UShortIListConverter()
 """

class VectorCollectionValueSerializer(ValueSerializer):
 """
 Converts instances of System.String to and from instances of System.Windows.Media.VectorCollection.

 

 VectorCollectionValueSerializer()
 """
 def CanConvertFromString(self,value,context):
  """
  CanConvertFromString(self: VectorCollectionValueSerializer,value: str,context: IValueSerializerContext) -> bool

  

   Determines if conversion from a given System.String to an instance of 

    System.Windows.Media.VectorCollection is possible.

  

  

   value: String to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if the value can be converted; otherwise,false.
  """
  pass
 def CanConvertToString(self,value,context):
  """
  CanConvertToString(self: VectorCollectionValueSerializer,value: object,context: IValueSerializerContext) -> bool

  

   Determines if an instance of System.Windows.Media.VectorCollection can be converted to a 

    System.String.

  

  

   value: Instance of System.Windows.Media.VectorCollection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: true if value can be converted into a System.String; otherwise,false.
  """
  pass
 def ConvertFromString(self,value,context):
  """
  ConvertFromString(self: VectorCollectionValueSerializer,value: str,context: IValueSerializerContext) -> object

  

   Converts a System.String into a System.Windows.Media.VectorCollection.

  

   value: System.String value to convert into a System.Windows.Media.VectorCollection.

   context: Context information used for conversion.

   Returns: A new instance of System.Windows.Media.VectorCollection based on the supplied value.
  """
  pass
 def ConvertToString(self,value,context):
  """
  ConvertToString(self: VectorCollectionValueSerializer,value: object,context: IValueSerializerContext) -> str

  

   Converts an instance of System.Windows.Media.VectorCollection to a System.String.

  

   value: Instance of System.Windows.Media.VectorCollection to evaluate for conversion.

   context: Context information used for conversion.

   Returns: A System.String representation of the supplied System.Windows.Media.VectorCollection object.
  """
  pass




class ButtonRenderer(object):
 """ Provides methods used to render a button control with or without visual styles. This class cannot be inherited. """
 @staticmethod
 def DrawButton(g,bounds,*__args):
  """
  DrawButton(g: Graphics,bounds: Rectangle,image: Image,imageBounds: Rectangle,focused: bool,state: PushButtonState)

   Draws a button control in the specified state and bounds,with the specified image,and with an 

    optional focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the button.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the button.

   image: The System.Drawing.Image to draw on the button.

   imageBounds: The System.Drawing.Rectangle that represents the dimensions of image.

   focused: true to draw a focus rectangle on the button; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.PushButtonState values that specifies the visual 

    state of the button.

  

  DrawButton(g: Graphics,bounds: Rectangle,buttonText: str,font: Font,image: Image,imageBounds: Rectangle,focused: bool,state: PushButtonState)

   Draws a button control in the specified state and bounds,with the specified text and image,and 

    with an optional focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the button.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the button.

   buttonText: The System.String to draw on the button.

   font: The System.Drawing.Font to apply to buttonText.

   image: The System.Drawing.Image to draw on the button.

   imageBounds: The System.Drawing.Rectangle that represents the dimensions of image.

   focused: true to draw a focus rectangle on the button; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.PushButtonState values that specifies the visual 

    state of the button.

  

  DrawButton(g: Graphics,bounds: Rectangle,buttonText: str,font: Font,flags: TextFormatFlags,image: Image,imageBounds: Rectangle,focused: bool,state: PushButtonState)

   Draws a button control in the specified state and bounds; with the specified text,text 

    formatting,and image; and with an optional focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the button.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the button.

   buttonText: The System.String to draw on the button.

   font: The System.Drawing.Font to apply to buttonText.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values to apply to buttonText.

   image: The System.Drawing.Image to draw on the button.

   imageBounds: The System.Drawing.Rectangle that represents the dimensions of image.

   focused: true to draw a focus rectangle on the button; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.PushButtonState values that specifies the visual 

    state of the button.

  

  DrawButton(g: Graphics,bounds: Rectangle,buttonText: str,font: Font,flags: TextFormatFlags,focused: bool,state: PushButtonState)

   Draws a button control in the specified state and bounds,with the specified text and text 

    formatting,and with an optional focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the button.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the button.

   buttonText: The System.String to draw on the button.

   font: The System.Drawing.Font to apply to buttonText.

   flags: A bitwise combination of the System.Windows.Forms.TextFormatFlags values to apply to buttonText.

   focused: true to draw a focus rectangle on the button; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.PushButtonState values that specifies the visual 

    state of the button.

  

  DrawButton(g: Graphics,bounds: Rectangle,state: PushButtonState)

   Draws a button control in the specified state and bounds.

  

   g: The System.Drawing.Graphics used to draw the button.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the button.

   state: One of the System.Windows.Forms.VisualStyles.PushButtonState values that specifies the visual 

    state of the button.

  

  DrawButton(g: Graphics,bounds: Rectangle,focused: bool,state: PushButtonState)

   Draws a button control in the specified state and bounds,and with an optional focus rectangle.

  

   g: The System.Drawing.Graphics used to draw the button.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the button.

   focused: true to draw a focus rectangle on the button; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.PushButtonState values that specifies the visual 

    state of the button.

  

  DrawButton(g: Graphics,bounds: Rectangle,buttonText: str,font: Font,focused: bool,state: PushButtonState)

   Draws a button control in the specified state and bounds,with the specified text,and with an 

    optional focus rectangle.

  

  

   g: The System.Drawing.Graphics used to draw the button.

   bounds: The System.Drawing.Rectangle that specifies the bounds of the button.

   buttonText: The System.String to draw on the button.

   font: The System.Drawing.Font to apply to buttonText.

   focused: true to draw a focus rectangle on the button; otherwise,false.

   state: One of the System.Windows.Forms.VisualStyles.PushButtonState values that specifies the visual 

    state of the button.
  """
  pass
 @staticmethod
 def DrawParentBackground(g,bounds,childControl):
  """
  DrawParentBackground(g: Graphics,bounds: Rectangle,childControl: Control)

   Draws the background of a control's parent in the specified area.

  

   g: The System.Drawing.Graphics used to draw the background of the parent of childControl.

   bounds: The System.Drawing.Rectangle in which to draw the parent control's background. This rectangle 

    

   childControl: The control whose parent's background will be drawn.
  """
  pass
 @staticmethod
 def IsBackgroundPartiallyTransparent(state):
  """
  IsBackgroundPartiallyTransparent(state: PushButtonState) -> bool

  

   Indicates whether the background of the button has semitransparent or alpha-blended pieces.

  

   state: One of the System.Windows.Forms.VisualStyles.PushButtonState values that specifies the visual 

    state of the button.

  

   Returns: true if the background of the button has semitransparent or alpha-blended pieces; otherwise,

    false.
  """
  pass
 RenderMatchingApplicationState=True




class ToolStripItemImageRenderEventArgs(ToolStripItemRenderEventArgs):
 """
 Provides data for the System.Windows.Forms.ToolStripRenderer.RenderItemImage event.

 

 ToolStripItemImageRenderEventArgs(g: Graphics,item: ToolStripItem,imageRectangle: Rectangle)

 ToolStripItemImageRenderEventArgs(g: Graphics,item: ToolStripItem,image: Image,imageRectangle: Rectangle)
 """
 @staticmethod
 def __new__(self,g,item,*__args):
  """
  __new__(cls: type,g: Graphics,item: ToolStripItem,imageRectangle: Rectangle)

  __new__(cls: type,g: Graphics,item: ToolStripItem,image: Image,imageRectangle: Rectangle)
  """
  pass
 Image=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the image painted on the System.Windows.Forms.ToolStrip.



Get: Image(self: ToolStripItemImageRenderEventArgs) -> Image



"""

 ImageRectangle=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the rectangle that represents the bounding area of the image.



Get: ImageRectangle(self: ToolStripItemImageRenderEventArgs) -> Rectangle



"""





class ITypeLibExporterNameProvider:
 """ Provides control over the casing of names when exported to a type library. """
 def GetNames(self):
  """
  GetNames(self: ITypeLibExporterNameProvider) -> Array[str]

  

   Returns a list of names to control the casing of.

   Returns: An array of strings,where each element contains the name of a type to control casing for.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass



class BaseCollection(MarshalByRefObject,ICollection,IEnumerable):
 """
 Provides the base functionality for creating data-related collections in the System.Windows.Forms namespace.

 

 BaseCollection()
 """
 def CopyTo(self,ar,index):
  """
  CopyTo(self: BaseCollection,ar: Array,index: int)

   Copies all the elements of the current one-dimensional System.Array to the specified 

    one-dimensional System.Array starting at the specified destination System.Array index.

  

  

   ar: The one-dimensional System.Array that is the destination of the elements copied from the current 

    Array.

  

   index: The zero-based relative index in ar at which copying begins.
  """
  pass
 def GetEnumerator(self):
  """
  GetEnumerator(self: BaseCollection) -> IEnumerator

  

   Gets the object that enables iterating through the members of the collection.

   Returns: An object that implements the System.Collections.IEnumerator interface.
  """
  pass
 def MemberwiseClone(self,*args):
  """
  MemberwiseClone(self: MarshalByRefObject,cloneIdentity: bool) -> MarshalByRefObject

  

   Creates a shallow copy of the current System.MarshalByRefObject object.

  

   cloneIdentity: false to delete the current System.MarshalByRefObject object's identity,which will cause the 

    object to be assigned a new identity when it is marshaled across a remoting boundary. A value of 

    false is usually appropriate. true to copy the current System.MarshalByRefObject object's 

    identity to its clone,which will cause remoting client calls to be routed to the remote server 

    object.

  

   Returns: A shallow copy of the current System.MarshalByRefObject object.

  MemberwiseClone(self: object) -> object

  

   Creates a shallow copy of the current System.Object.

   Returns: A shallow copy of the current System.Object.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __len__(self,*args):
  """ x.__len__() <==> len(x) """
  pass
 Count=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the total number of elements in the collection.



Get: Count(self: BaseCollection) -> int



"""

 IsReadOnly=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether the collection is read-only.



Get: IsReadOnly(self: BaseCollection) -> bool



"""

 IsSynchronized=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value indicating whether access to the System.Collections.ICollection is synchronized.



Get: IsSynchronized(self: BaseCollection) -> bool



"""

 List=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the list of elements contained in the System.Windows.Forms.BaseCollection instance.



"""

 SyncRoot=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets an object that can be used to synchronize access to the System.Windows.Forms.BaseCollection.



Get: SyncRoot(self: BaseCollection) -> object



"""





# encoding: utf-8
# module System.Windows.Annotations calls itself Annotations
# from PresentationFramework,Version=4.0.0.0,Culture=neutral,PublicKeyToken=31bf3856ad364e35
# by generator 1.145
""" NamespaceTracker represent a CLS namespace. """
# no imports

# no functions
# classes

class Annotation(object,IXmlSerializable):
 """
 Represents a user annotation in the Microsoft Annotations Framework.

 

 Annotation()

 Annotation(annotationType: XmlQualifiedName)

 Annotation(annotationType: XmlQualifiedName,id: Guid,creationTime: DateTime,lastModificationTime: DateTime)
 """
 def GetSchema(self):
  """
  GetSchema(self: Annotation) -> XmlSchema

  

   Always returns null.  See Annotations Schema for schema details.

   Returns: Always null.  See Annotations Schema for schema details.
  """
  pass
 def ReadXml(self,reader):
  """
  ReadXml(self: Annotation,reader: XmlReader)

   Deserializes the System.Windows.Annotations.Annotation from a specified System.Xml.XmlReader.

  

   reader: The XML reader to use to deserialize the annotation.
  """
  pass
 def WriteXml(self,writer):
  """
  WriteXml(self: Annotation,writer: XmlWriter)

   Serializes the annotation to a specified System.Xml.XmlWriter.

  

   writer: The XML writer to use to serialize the annotation.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,annotationType=None,id=None,creationTime=None,lastModificationTime=None):
  """
  __new__(cls: type)

  __new__(cls: type,annotationType: XmlQualifiedName)

  __new__(cls: type,annotationType: XmlQualifiedName,id: Guid,creationTime: DateTime,lastModificationTime: DateTime)
  """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 Anchors=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection of zero or more System.Windows.Annotations.AnnotationResource anchor elements that define the data selection(s) being annotated.



Get: Anchors(self: Annotation) -> Collection[AnnotationResource]



"""

 AnnotationType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Xml.XmlQualifiedName of the annotation type.



Get: AnnotationType(self: Annotation) -> XmlQualifiedName



"""

 Authors=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection of zero or more author strings that identify who created the System.Windows.Annotations.Annotation.



Get: Authors(self: Annotation) -> Collection[str]



"""

 Cargos=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection of zero or more System.Windows.Annotations.AnnotationResource cargo elements that contain data for the annotation.



Get: Cargos(self: Annotation) -> Collection[AnnotationResource]



"""

 CreationTime=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the date and the time that the annotation was created.



Get: CreationTime(self: Annotation) -> DateTime



"""

 Id=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the globally unique identifier (GUID) of the System.Windows.Annotations.Annotation.



Get: Id(self: Annotation) -> Guid



"""

 LastModificationTime=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the date and the time that the annotation was last modified.



Get: LastModificationTime(self: Annotation) -> DateTime



"""


 AnchorChanged=None
 AuthorChanged=None
 CargoChanged=None


class AnnotationAction(Enum,IComparable,IFormattable,IConvertible):
 """
 Specifies the actions that occur with System.Windows.Annotations.Annotation author,anchor,and cargo resources.

 

 enum AnnotationAction,values: Added (0),Modified (2),Removed (1)
 """
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==yx.__eq__(y) <==> x==yx.__eq__(y) <==> x==y """
  pass
 def __format__(self,*args):
  """ __format__(formattable: IFormattable,format: str) -> str """
  pass
 def __ge__(self,*args):
  pass
 def __gt__(self,*args):
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __le__(self,*args):
  pass
 def __lt__(self,*args):
  pass
 def __ne__(self,*args):
  pass
 def __reduce_ex__(self,*args):
  pass
 def __str__(self,*args):
  pass
 Added=None
 Modified=None
 Removed=None
 value__=None


class AnnotationAuthorChangedEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Annotations.Annotation.AuthorChanged event.

 

 AnnotationAuthorChangedEventArgs(annotation: Annotation,action: AnnotationAction,author: object)
 """
 @staticmethod
 def __new__(self,annotation,action,author):
  """ __new__(cls: type,annotation: Annotation,action: AnnotationAction,author: object) """
  pass
 Action=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the author change operation for the event.



Get: Action(self: AnnotationAuthorChangedEventArgs) -> AnnotationAction



"""

 Annotation=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the annotation that raised the event.



Get: Annotation(self: AnnotationAuthorChangedEventArgs) -> Annotation



"""

 Author=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the author object that is the target of the event.



Get: Author(self: AnnotationAuthorChangedEventArgs) -> object



"""



class AnnotationAuthorChangedEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that handles the System.Windows.Annotations.Annotation.AuthorChanged event raised by the System.Windows.Annotations.Annotation class.

 

 AnnotationAuthorChangedEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: AnnotationAuthorChangedEventHandler,sender: object,e: AnnotationAuthorChangedEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: AnnotationAuthorChangedEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: AnnotationAuthorChangedEventHandler,sender: object,e: AnnotationAuthorChangedEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class AnnotationDocumentPaginator(DocumentPaginator):
 """
 Provides a System.Windows.Documents.DocumentPaginator for printing a document together with its associated annotations.

 

 AnnotationDocumentPaginator(originalPaginator: DocumentPaginator,annotationStore: Stream)

 AnnotationDocumentPaginator(originalPaginator: DocumentPaginator,annotationStore: Stream,flowDirection: FlowDirection)

 AnnotationDocumentPaginator(originalPaginator: DocumentPaginator,annotationStore: AnnotationStore)

 AnnotationDocumentPaginator(originalPaginator: DocumentPaginator,annotationStore: AnnotationStore,flowDirection: FlowDirection)
 """
 def CancelAsync(self,userState):
  """
  CancelAsync(self: AnnotationDocumentPaginator,userState: object)

   Cancels all asynchronous operations initiated with a given userState object.

  

   userState: The unique application-defined identifier passed in the call to start the asynchronous operation.
  """
  pass
 def ComputePageCount(self):
  """
  ComputePageCount(self: AnnotationDocumentPaginator)

   Forces a pagination of the content,updates 

    System.Windows.Annotations.AnnotationDocumentPaginator.PageCount with the new total,and sets 

    System.Windows.Annotations.AnnotationDocumentPaginator.IsPageCountValid to true.
  """
  pass
 def ComputePageCountAsync(self,userState=None):
  """
  ComputePageCountAsync(self: AnnotationDocumentPaginator,userState: object)

   Starts an asynchronous pagination of the content,updates 

    System.Windows.Annotations.AnnotationDocumentPaginator.PageCount with the new total,and sets 

    System.Windows.Annotations.AnnotationDocumentPaginator.IsPageCountValid to true when it is 

    finished.

  

  

   userState: An application-defined object for identifying the asynchronous operation.
  """
  pass
 def GetPage(self,pageNumber):
  """
  GetPage(self: AnnotationDocumentPaginator,pageNumber: int) -> DocumentPage

  

   Returns a System.Windows.Documents.DocumentPage together with associated user-annotations for a 

    specified page number.

  

  

   pageNumber: The zero-based page number of the System.Windows.Documents.DocumentPage to return.

   Returns: The System.Windows.Documents.DocumentPage for the specified pageNumber; or 

    System.Windows.Documents.DocumentPage.Missing,if the specified pageNumber does not exist.
  """
  pass
 def GetPageAsync(self,pageNumber,userState=None):
  """
  GetPageAsync(self: AnnotationDocumentPaginator,pageNumber: int,userState: object)

   asynchronously returns a System.Windows.Documents.DocumentPage together with associated 

    user-annotations for a specified page number.

  

  

   pageNumber: The zero-based page number of the System.Windows.Documents.DocumentPage to retrieve.

   userState: An application-defined object that is used to identify the asynchronous operation.
  """
  pass
 @staticmethod
 def __new__(self,originalPaginator,annotationStore,flowDirection=None):
  """
  __new__(cls: type,originalPaginator: DocumentPaginator,annotationStore: Stream)

  __new__(cls: type,originalPaginator: DocumentPaginator,annotationStore: Stream,flowDirection: FlowDirection)

  __new__(cls: type,originalPaginator: DocumentPaginator,annotationStore: AnnotationStore)

  __new__(cls: type,originalPaginator: DocumentPaginator,annotationStore: AnnotationStore,flowDirection: FlowDirection)
  """
  pass
 IsPageCountValid=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether System.Windows.Annotations.AnnotationDocumentPaginator.PageCount is the total number of pages.



Get: IsPageCountValid(self: AnnotationDocumentPaginator) -> bool



"""

 PageCount=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates the number of pages currently formatted.



Get: PageCount(self: AnnotationDocumentPaginator) -> int



"""

 PageSize=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets the suggested width and height of each page.



Get: PageSize(self: AnnotationDocumentPaginator) -> Size



Set: PageSize(self: AnnotationDocumentPaginator)=value

"""

 Source=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the source document that is being paginated.



Get: Source(self: AnnotationDocumentPaginator) -> IDocumentPaginatorSource



"""



class AnnotationHelper(object):
 """ Provides utility methods and commands to create and delete highlight,ink sticky note,and text sticky note annotations. """
 @staticmethod
 def ClearHighlightsForSelection(service):
  """
  ClearHighlightsForSelection(service: AnnotationService)

   Clears all highlight annotations from the current selection of the viewer control associated 

    with the given System.Windows.Annotations.AnnotationService.

  

  

   service: The annotation service from which to remove highlight annotations.
  """
  pass
 @staticmethod
 def CreateHighlightForSelection(service,author,highlightBrush):
  """
  CreateHighlightForSelection(service: AnnotationService,author: str,highlightBrush: Brush) -> Annotation

  

   Creates a highlight annotation on the current selection of the viewer control associated with 

    the specified System.Windows.Annotations.AnnotationService.

  

  

   service: The annotation service to use to create the highlight annotation.

   author: The author of the annotation.

   highlightBrush: The brush to use to draw the highlight over the selected content.

   Returns: The highlight annotation; or null,if there is no selected content to highlight.
  """
  pass
 @staticmethod
 def CreateInkStickyNoteForSelection(service,author):
  """
  CreateInkStickyNoteForSelection(service: AnnotationService,author: str) -> Annotation

  

   Creates an ink sticky note annotation on the current selection of the viewer control associated 

    with the specified System.Windows.Annotations.AnnotationService..

  

  

   service: The annotation service to use to create the ink sticky note annotation.

   author: The author of the annotation.

   Returns: The ink sticky note annotation; or null,if there is no selected content to annotate.
  """
  pass
 @staticmethod
 def CreateTextStickyNoteForSelection(service,author):
  """
  CreateTextStickyNoteForSelection(service: AnnotationService,author: str) -> Annotation

  

   Creates a text sticky note annotation on the current selection of the viewer control associated 

    with the specified System.Windows.Annotations.AnnotationService.

  

  

   service: The annotation service to use to create the text sticky note annotation.

   author: The author of the annotation.

   Returns: The text sticky note annotation; or null,if there is no selected content to annotate.
  """
  pass
 @staticmethod
 def DeleteInkStickyNotesForSelection(service):
  """
  DeleteInkStickyNotesForSelection(service: AnnotationService)

   Deletes ink sticky note annotations that are wholly contained within the current selection of 

    the viewer control associated with the given System.Windows.Annotations.AnnotationService.

  

  

   service: The annotation service from which to delete ink sticky note annotations.
  """
  pass
 @staticmethod
 def DeleteTextStickyNotesForSelection(service):
  """
  DeleteTextStickyNotesForSelection(service: AnnotationService)

   Deletes text sticky note annotations that are wholly contained within the current selection of 

    the viewer control associated with the given System.Windows.Annotations.AnnotationService.

  

  

   service: The annotation service from which to delete text sticky note annotations.
  """
  pass
 @staticmethod
 def GetAnchorInfo(service,annotation):
  """
  GetAnchorInfo(service: AnnotationService,annotation: Annotation) -> IAnchorInfo

  

   Returns an System.Windows.Annotations.IAnchorInfo object that provides anchoring information,

    such as the anchor location,about the specified annotation.

  

  

   service: The annotation service to use for this operation.

   annotation: The annotation to get anchoring information for.

   Returns: An System.Windows.Annotations.IAnchorInfo object that provides anchoring information about the 

    specified annotation,or null if it cannot be resolved.
  """
  pass
 __all__=[
  'ClearHighlightsForSelection',
  'CreateHighlightForSelection',
  'CreateInkStickyNoteForSelection',
  'CreateTextStickyNoteForSelection',
  'DeleteInkStickyNotesForSelection',
  'DeleteTextStickyNotesForSelection',
  'GetAnchorInfo',
 ]


class AnnotationResource(object,IXmlSerializable,INotifyPropertyChanged2,INotifyPropertyChanged,IOwnedObject):
 """
 Represents a content anchor or cargo resource for an System.Windows.Annotations.Annotation.

 

 AnnotationResource()

 AnnotationResource(name: str)

 AnnotationResource(id: Guid)
 """
 def GetSchema(self):
  """
  GetSchema(self: AnnotationResource) -> XmlSchema

  

   Always returns null.  See Annotations Schema for schema details.

   Returns: Always null.  See Annotations Schema for schema details.
  """
  pass
 def ReadXml(self,reader):
  """
  ReadXml(self: AnnotationResource,reader: XmlReader)

   Deserializes the System.Windows.Annotations.AnnotationResource from a specified 

    System.Xml.XmlReader.

  

  

   reader: The XML reader to deserialize the System.Windows.Annotations.AnnotationResource from.
  """
  pass
 def WriteXml(self,writer):
  """
  WriteXml(self: AnnotationResource,writer: XmlWriter)

   Serializes the System.Windows.Annotations.AnnotationResource to a specified System.Xml.XmlWriter.

  

   writer: The XML writer to serialize the System.Windows.Annotations.AnnotationResource.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,*__args):
  """
  __new__(cls: type)

  __new__(cls: type,name: str)

  __new__(cls: type,id: Guid)
  """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 ContentLocators=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of System.Windows.Annotations.ContentLocatorBase elements contained in this resource.



Get: ContentLocators(self: AnnotationResource) -> Collection[ContentLocatorBase]



"""

 Contents=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection of the System.Xml.XmlElement objects that define the content of this resource.



Get: Contents(self: AnnotationResource) -> Collection[XmlElement]



"""

 Id=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the GUID of this resource.



Get: Id(self: AnnotationResource) -> Guid



"""

 Name=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets or sets a name for this System.Windows.Annotations.AnnotationResource.



Get: Name(self: AnnotationResource) -> str



Set: Name(self: AnnotationResource)=value

"""



class AnnotationResourceChangedEventArgs(EventArgs):
 """
 Provides data for the System.Windows.Annotations.Annotation.AnchorChanged and System.Windows.Annotations.Annotation.CargoChanged events.

 

 AnnotationResourceChangedEventArgs(annotation: Annotation,action: AnnotationAction,resource: AnnotationResource)
 """
 @staticmethod
 def __new__(self,annotation,action,resource):
  """ __new__(cls: type,annotation: Annotation,action: AnnotationAction,resource: AnnotationResource) """
  pass
 Action=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the action of the annotation System.Windows.Annotations.AnnotationResourceChangedEventArgs.Resource.



Get: Action(self: AnnotationResourceChangedEventArgs) -> AnnotationAction



"""

 Annotation=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Annotations.Annotation that raised the event.



Get: Annotation(self: AnnotationResourceChangedEventArgs) -> Annotation



"""

 Resource=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Annotations.Annotation.Anchors or System.Windows.Annotations.Annotation.Cargos resource associated with the event.



Get: Resource(self: AnnotationResourceChangedEventArgs) -> AnnotationResource



"""



class AnnotationResourceChangedEventHandler(MulticastDelegate,ICloneable,ISerializable):
 """
 Represents the method that handles the System.Windows.Annotations.Annotation.AnchorChanged or System.Windows.Annotations.Annotation.CargoChanged events raised by the System.Windows.Annotations.Annotation class.

 

 AnnotationResourceChangedEventHandler(object: object,method: IntPtr)
 """
 def BeginInvoke(self,sender,e,callback,object):
  """ BeginInvoke(self: AnnotationResourceChangedEventHandler,sender: object,e: AnnotationResourceChangedEventArgs,callback: AsyncCallback,object: object) -> IAsyncResult """
  pass
 def CombineImpl(self,*args):
  """
  CombineImpl(self: MulticastDelegate,follow: Delegate) -> Delegate

  

   Combines this System.Delegate with the specified System.Delegate to form a new delegate.

  

   follow: The delegate to combine with this delegate.

   Returns: A delegate that is the new root of the System.MulticastDelegate invocation list.
  """
  pass
 def DynamicInvokeImpl(self,*args):
  """
  DynamicInvokeImpl(self: Delegate,args: Array[object]) -> object

  

   Dynamically invokes (late-bound) the method represented by the current delegate.

  

   args: An array of objects that are the arguments to pass to the method represented by the current 

    delegate.-or- null,if the method represented by the current delegate does not require 

    arguments.

  

   Returns: The object returned by the method represented by the delegate.
  """
  pass
 def EndInvoke(self,result):
  """ EndInvoke(self: AnnotationResourceChangedEventHandler,result: IAsyncResult) """
  pass
 def GetMethodImpl(self,*args):
  """
  GetMethodImpl(self: MulticastDelegate) -> MethodInfo

  

   Returns a static method represented by the current System.MulticastDelegate.

   Returns: A static method represented by the current System.MulticastDelegate.
  """
  pass
 def Invoke(self,sender,e):
  """ Invoke(self: AnnotationResourceChangedEventHandler,sender: object,e: AnnotationResourceChangedEventArgs) """
  pass
 def RemoveImpl(self,*args):
  """
  RemoveImpl(self: MulticastDelegate,value: Delegate) -> Delegate

  

   Removes an element from the invocation list of this System.MulticastDelegate that is equal to 

    the specified delegate.

  

  

   value: The delegate to search for in the invocation list.

   Returns: If value is found in the invocation list for this instance,then a new System.Delegate without 

    value in its invocation list; otherwise,this instance with its original invocation list.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,object,method):
  """ __new__(cls: type,object: object,method: IntPtr) """
  pass
 def __reduce_ex__(self,*args):
  pass

class AnnotationService(DispatcherObject):
 """
 Provides core services of the Microsoft Annotations Framework�to manage and display user annotations.

 

 AnnotationService(viewer: DocumentViewerBase)

 AnnotationService(viewer: FlowDocumentScrollViewer)

 AnnotationService(viewer: FlowDocumentReader)
 """
 def Disable(self):
  """
  Disable(self: AnnotationService)

   Disables annotations processing and hides all visible annotations.
  """
  pass
 def Enable(self,annotationStore):
  """
  Enable(self: AnnotationService,annotationStore: AnnotationStore)

   Enables the System.Windows.Annotations.AnnotationService for use with a given 

    System.Windows.Annotations.Storage.AnnotationStore and displays all visible annotations.

  

  

   annotationStore: The annotation store to use for reading,writing,and displaying annotations.
  """
  pass
 @staticmethod
 def GetService(*__args):
  """
  GetService(viewer: FlowDocumentScrollViewer) -> AnnotationService

  

   Returns the System.Windows.Annotations.AnnotationService associated with a specified 

    System.Windows.Controls.FlowDocumentScrollViewer.

  

  

   viewer: The document viewer control to return the System.Windows.Annotations.AnnotationService instance 

    for.

  

   Returns: The System.Windows.Annotations.AnnotationService associated with the given document viewer 

    control; or null if the specified viewer control has no 

    System.Windows.Annotations.AnnotationService.

  

  GetService(reader: FlowDocumentReader) -> AnnotationService

  

   Returns the System.Windows.Annotations.AnnotationService associated with a specified 

    System.Windows.Controls.FlowDocumentReader.

  

  

   reader: The document reader control to return the System.Windows.Annotations.AnnotationService instance 

    for.

  

   Returns: The System.Windows.Annotations.AnnotationService associated with the given document reader 

    control; or null if the specified document reader has no 

    System.Windows.Annotations.AnnotationService.

  

  GetService(viewer: DocumentViewerBase) -> AnnotationService

  

   Returns the System.Windows.Annotations.AnnotationService instance associated with a specified 

    document viewing control.

  

  

   viewer: The document viewing control to return the System.Windows.Annotations.AnnotationService instance 

    for.

  

   Returns: The System.Windows.Annotations.AnnotationService associated with the given document viewing 

    control; or null if the specified document viewing control has no 

    System.Windows.Annotations.AnnotationService.
  """
  pass
 @staticmethod
 def __new__(self,viewer):
  """
  __new__(cls: type,viewer: DocumentViewerBase)

  __new__(cls: type,viewer: FlowDocumentScrollViewer)

  __new__(cls: type,viewer: FlowDocumentReader)
  """
  pass
 IsEnabled=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a value that indicates whether the System.Windows.Annotations.AnnotationService is enabled.



Get: IsEnabled(self: AnnotationService) -> bool



"""

 Store=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the System.Windows.Annotations.Storage.AnnotationStore used by this System.Windows.Annotations.AnnotationService.



Get: Store(self: AnnotationService) -> AnnotationStore



"""


 ClearHighlightsCommand=None
 CreateHighlightCommand=None
 CreateInkStickyNoteCommand=None
 CreateTextStickyNoteCommand=None
 DeleteAnnotationsCommand=None
 DeleteStickyNotesCommand=None


class ContentLocatorBase(object,INotifyPropertyChanged2,INotifyPropertyChanged,IOwnedObject):
 """ Represents an object that identifies an item of content. """
 def Clone(self):
  """
  Clone(self: ContentLocatorBase) -> object

  

   Creates a modifiable deep copy clone of this System.Windows.Annotations.ContentLocatorBase.

   Returns: A modifiable deep copy clone of this System.Windows.Annotations.ContentLocatorBase.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass

class ContentLocator(ContentLocatorBase,INotifyPropertyChanged2,INotifyPropertyChanged,IOwnedObject,IXmlSerializable):
 """
 Represents an ordered set of System.Windows.Annotations.ContentLocatorPart elements that identify an item of content.

 

 ContentLocator()
 """
 def Clone(self):
  """
  Clone(self: ContentLocator) -> object

  

   Creates a modifiable deep copy clone of this System.Windows.Annotations.ContentLocator.

   Returns: A modifiable deep copy clone of this System.Windows.Annotations.ContentLocator.
  """
  pass
 def GetSchema(self):
  """
  GetSchema(self: ContentLocator) -> XmlSchema

  

   Always returns null.  See Annotations Schema for schema details.

   Returns: Always null.  See Annotations Schema for schema details
  """
  pass
 def ReadXml(self,reader):
  """
  ReadXml(self: ContentLocator,reader: XmlReader)

   Deserializes the System.Windows.Annotations.ContentLocator from a specified System.Xml.XmlReader.

  

   reader: The XML reader to use to deserialize the System.Windows.Annotations.ContentLocator.
  """
  pass
 def StartsWith(self,locator):
  """
  StartsWith(self: ContentLocator,locator: ContentLocator) -> bool

  

   Returns a value that indicates whether the starting sequence of 

    System.Windows.Annotations.ContentLocatorPart elements in a specified 

    System.Windows.Annotations.ContentLocator are identical to those in this 

    System.Windows.Annotations.ContentLocator.

  

  

   locator: The System.Windows.Annotations.ContentLocator with the list of 

    System.Windows.Annotations.ContentLocatorPart elements to compare with this 

    System.Windows.Annotations.ContentLocator.

  

   Returns: true if the starting sequence of System.Windows.Annotations.ContentLocatorPart elements in this 

    System.Windows.Annotations.ContentLocator matches those in the specified locator; otherwise,

    false.
  """
  pass
 def WriteXml(self,writer):
  """
  WriteXml(self: ContentLocator,writer: XmlWriter)

   Serializes the System.Windows.Annotations.ContentLocator to a specified System.Xml.XmlWriter.

  

   writer: The XML writer to use to serialize the System.Windows.Annotations.ContentLocator.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 Parts=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of System.Windows.Annotations.ContentLocatorPart elements that make up this System.Windows.Annotations.ContentLocator.



Get: Parts(self: ContentLocator) -> Collection[ContentLocatorPart]



"""



class ContentLocatorGroup(ContentLocatorBase,INotifyPropertyChanged2,INotifyPropertyChanged,IOwnedObject,IXmlSerializable):
 """
 Represents an ordered set of System.Windows.Annotations.ContentLocator elements that identify an item of content.

 

 ContentLocatorGroup()
 """
 def Clone(self):
  """
  Clone(self: ContentLocatorGroup) -> object

  

   Creates a modifiable deep copy clone of this System.Windows.Annotations.ContentLocatorGroup.

   Returns: A modifiable deep copy clone of this System.Windows.Annotations.ContentLocatorGroup.
  """
  pass
 def GetSchema(self):
  """
  GetSchema(self: ContentLocatorGroup) -> XmlSchema

  

   Always returns null.  See Annotations Schema for schema details.

   Returns: Always null.  See Annotations Schema for schema details.
  """
  pass
 def ReadXml(self,reader):
  """
  ReadXml(self: ContentLocatorGroup,reader: XmlReader)

   Deserializes the System.Windows.Annotations.ContentLocatorGroup from a specified 

    System.Xml.XmlReader.

  

  

   reader: The XML reader to use to deserialize the System.Windows.Annotations.ContentLocatorGroup.
  """
  pass
 def WriteXml(self,writer):
  """
  WriteXml(self: ContentLocatorGroup,writer: XmlWriter)

   Serializes the System.Windows.Annotations.ContentLocatorGroup to a specified 

    System.Xml.XmlWriter.

  

  

   writer: The XML writer to use to serialize the System.Windows.Annotations.ContentLocatorGroup.
  """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 Locators=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the collection of the System.Windows.Annotations.ContentLocator elements that make up this System.Windows.Annotations.ContentLocatorGroup.



Get: Locators(self: ContentLocatorGroup) -> Collection[ContentLocator]



"""



class ContentLocatorPart(object,INotifyPropertyChanged2,INotifyPropertyChanged,IOwnedObject):
 """
 Represents a set of name/value pairs that identify an item of content.

 

 ContentLocatorPart(partType: XmlQualifiedName)
 """
 def Clone(self):
  """
  Clone(self: ContentLocatorPart) -> object

  

   Creates a modifiable deep copy clone of this System.Windows.Annotations.ContentLocatorPart.

   Returns: A modifiable deep copy clone of this System.Windows.Annotations.ContentLocatorPart.
  """
  pass
 def Equals(self,obj):
  """
  Equals(self: ContentLocatorPart,obj: object) -> bool

  

   Returns a value that indicates whether a given System.Windows.Annotations.ContentLocatorPart is 

    identical to this System.Windows.Annotations.ContentLocatorPart.

  

  

   obj: The part to compare for equality.

   Returns: true if the System.Windows.Annotations.ContentLocatorPart.NameValuePairs within both parts are 

    identical; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: ContentLocatorPart) -> int

  

   Returns the hash code for this part.

   Returns: The hash code for this part.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 @staticmethod
 def __new__(self,partType):
  """ __new__(cls: type,partType: XmlQualifiedName) """
  pass
 def __ne__(self,*args):
  pass
 def __repr__(self,*args):
  """ __repr__(self: object) -> str """
  pass
 NameValuePairs=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a collection of the name/value pairs that define this part.



Get: NameValuePairs(self: ContentLocatorPart) -> IDictionary[str,str]



"""

 PartType=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the type name and namespace of the part.



Get: PartType(self: ContentLocatorPart) -> XmlQualifiedName



"""



class IAnchorInfo:
 """ Provides the capabilities for matching annotations with the corresponding annotated objects. """
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 Anchor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the anchor of the annotation.



Get: Anchor(self: IAnchorInfo) -> AnnotationResource



"""

 Annotation=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the annotation object.



Get: Annotation(self: IAnchorInfo) -> Annotation



"""

 ResolvedAnchor=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the object that represents the location on the tree where the System.Windows.Annotations.IAnchorInfo.Anchor is resolved.



Get: ResolvedAnchor(self: IAnchorInfo) -> object



"""



class TextAnchor(object):
 """ Represents a selection of content that an annotation is anchored to. """
 def Equals(self,obj):
  """
  Equals(self: TextAnchor,obj: object) -> bool

  

   Returns a value that indicates whether the text anchor is equal to the specified object.

  

   obj: The object to compare to.

   Returns: true if the two instances are equal; otherwise,false.
  """
  pass
 def GetHashCode(self):
  """
  GetHashCode(self: TextAnchor) -> int

  

   Returns the hash code of the text anchor instance.

   Returns: The hash code of the text anchor instance.
  """
  pass
 def __eq__(self,*args):
  """ x.__eq__(y) <==> x==y """
  pass
 def __ne__(self,*args):
  pass
 BoundingEnd=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the end position of the text anchor.



Get: BoundingEnd(self: TextAnchor) -> ContentPosition



"""

 BoundingStart=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets the beginning position of the text anchor.



Get: BoundingStart(self: TextAnchor) -> ContentPosition



"""



# variables with complex values




class GridViewColumnCollection(ObservableCollection[GridViewColumn],IList[GridViewColumn],ICollection[GridViewColumn],IEnumerable[GridViewColumn],IEnumerable,IList,ICollection,IReadOnlyList[GridViewColumn],IReadOnlyCollection[GridViewColumn],INotifyCollectionChanged,INotifyPropertyChanged):
 """
 Represents a collection of System.Windows.Controls.GridViewColumn objects.

 

 GridViewColumnCollection()
 """
 def add_PropertyChanged(self,*args):
  """ add_PropertyChanged(self: ObservableCollection[GridViewColumn],value: PropertyChangedEventHandler) """
  pass
 def BlockReentrancy(self,*args):
  """
  BlockReentrancy(self: ObservableCollection[GridViewColumn]) -> IDisposable

  

   Disallows reentrant attempts to change this collection.

   Returns: An System.IDisposable object that can be used to dispose of the object.
  """
  pass
 def CheckReentrancy(self,*args):
  """
  CheckReentrancy(self: ObservableCollection[GridViewColumn])

   Checks for reentrant attempts to change this collection.
  """
  pass
 def ClearItems(self,*args):
  """
  ClearItems(self: GridViewColumnCollection)

   Removes all of the System.Windows.Controls.GridViewColumn objects from the 

    System.Windows.Controls.GridViewColumnCollection.
  """
  pass
 def InsertItem(self,*args):
  """
  InsertItem(self: GridViewColumnCollection,index: int,column: GridViewColumn)

   Adds a System.Windows.Controls.GridViewColumn to the collection at the specified index.

  

   index: The position to place the new System.Windows.Controls.GridViewColumn.

   column: The System.Windows.Controls.GridViewColumn to insert.
  """
  pass
 def MoveItem(self,*args):
  """
  MoveItem(self: GridViewColumnCollection,oldIndex: int,newIndex: int)

   Changes the position of a System.Windows.Controls.GridViewColumn in the collection.

  

   oldIndex: The original position of the System.Windows.Controls.GridViewColumn.

   newIndex: The new position of the System.Windows.Controls.GridViewColumn.
  """
  pass
 def OnCollectionChanged(self,*args):
  """
  OnCollectionChanged(self: GridViewColumnCollection,e: NotifyCollectionChangedEventArgs)

   Raises the System.Collections.ObjectModel.ObservableCollection event when the 

    System.Windows.Controls.GridViewColumnCollection changes.

  

  

   e: The event arguments.
  """
  pass
 def OnPropertyChanged(self,*args):
  """
  OnPropertyChanged(self: ObservableCollection[GridViewColumn],e: PropertyChangedEventArgs)

   Raises the System.Collections.ObjectModel.ObservableCollection event with the provided arguments.

  

   e: Arguments of the event being raised.
  """
  pass
 def RemoveItem(self,*args):
  """
  RemoveItem(self: GridViewColumnCollection,index: int)

   Removes a System.Windows.Controls.GridViewColumn from the 

    System.Windows.Controls.GridViewColumnCollection at the specified index.

  

  

   index: The position of the System.Windows.Controls.GridViewColumn to remove.
  """
  pass
 def remove_PropertyChanged(self,*args):
  """ remove_PropertyChanged(self: ObservableCollection[GridViewColumn],value: PropertyChangedEventHandler) """
  pass
 def SetItem(self,*args):
  """
  SetItem(self: GridViewColumnCollection,index: int,column: GridViewColumn)

   Replaces the System.Windows.Controls.GridViewColumn that is at the specified index with another 

    System.Windows.Controls.GridViewColumn.

  

  

   index: The position at which the new System.Windows.Controls.GridViewColumn replaces the old 

    System.Windows.Controls.GridViewColumn.

  

   column: The System.Windows.Controls.GridViewColumn to place at the specified position.
  """
  pass
 def __getitem__(self,*args):
  """ x.__getitem__(y) <==> x[y] """
  pass
 def __init__(self,*args):
  """ x.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signaturex.__init__(...) initializes x; see x.__class__.__doc__ for signature """
  pass
 def __iter__(self,*args):
  """ __iter__(self: IEnumerable) -> object """
  pass
 def __reduce_ex__(self,*args):
  pass
 def __setitem__(self,*args):
  """ x.__setitem__(i,y) <==> x[i]= """
  pass
 Items=property(lambda self: object(),lambda self,v: None,lambda self: None)
 """Gets a System.Collections.Generic.IList wrapper around the System.Collections.ObjectModel.Collection.



"""





# -*- coding: utf-8 -*-
"""Utility module for pyRevit project information.

Examples:
        ```python
        from pyrevit.versionmgr import about
        a = about.get_pyrevit_about()
        a.subtitle
        ```
        'python RAD Environment for Autodesk Revit®'a.copyright'© 2014-2025 Ehsan Iran-Nejad'
"""
from collections import namedtuple


# FIXME: tuple attrs have duplicate docs
PyRevitAbout = namedtuple('PyRevitAbout', ['subtitle', 'madein', 'copyright'])
"""pyRevit project info tuple.

Attributes:
    subtitle (str): project subtitle
    madein (str): project made-in info
    copyright (str): project copyright info
"""


def get_pyrevit_about():
    """Return information about pyRevit project.

    Returns:
        (PyRevitAbout): pyRevit project info tuple
    """
    return PyRevitAbout(subtitle='python RAD Environment for Autodesk Revit®',
                        madein="['pdx', 'hio', 'rno', 'sea']",
                        copyright='© 2014-2025 Ehsan Iran-Nejad')
